==> graypold-0.2.tar.bz2: graypold-0.2/graylib.pl <==
#!/usr/bin/perl

$CONFIG_FILE			= "/usr/local/etc/graypol.conf";
$DEFAULTS{"dbtype"}		= "Pg";
$DEFAULTS{"dbhost"}		= "";
$DEFAULTS{"dbport"}		= "";
$DEFAULTS{"dbuser"}		= "";
$DEFAULTS{"dbpass"}		= "";
$DEFAULTS{"dbname"}		= "";
$DEFAULTS{"db_tbl_gray"}	= "graylist";
$DEFAULTS{"db_tbl_bw"}		= "blackwhitelist";
$DEFAULTS{"db_field_ok"}	= "ok";
$DEFAULTS{"db_field_ip"}	= "ip";
$DEFAULTS{"db_field_from"}	= "\"from\"";
$DEFAULTS{"db_field_to"}	= "\"to\"";
$DEFAULTS{"db_field_ts_entry"}	= "ts_entry";
$DEFAULTS{"db_field_ts_latest"}	= "ts_latest";
$DEFAULTS{"db_field_ts_ok"}	= "ts_ok";
$DEFAULTS{"db_field_count"}	= "count";
$DEFAULTS{"db_key_err"}		= "duplicate key violates unique constraint";
$DEFAULTS{"listen"}		= "/var/run/graypold.sock";
$DEFAULTS{"owner"}		= "postfix";
$DEFAULTS{"rights"}		= "0600";
$DEFAULTS{"port"}		= "6666";
$DEFAULTS{"backlog"}		= "128";
$DEFAULTS{"pidfile"}		= "/var/run/graypold.pid";

$DEFAULTS{"lockfile"}		= "/var/lock/graycron.lock";
$DEFAULTS{"rrdfile"}		= "/var/db/graylist.rrd";
$DEFAULTS{"picpath"}		= "/usr/local/www/data";
$DEFAULTS{"delay_permit"}	= "interval '3 minutes'";
$DEFAULTS{"delay_halfopen"}	= "interval '12 hours'";
$DEFAULTS{"delay_max"}		= "interval '35 days'";

%config = %DEFAULTS;

sub dbopen ()
{
  %attr = ( RaiseError => 1, PrintError => 0, HandleError => $_[0] ) if $_[0];
  $dsn = "DBI:$config{dbtype}:dbname=$config{dbname}";
  $dsn .= ";host=$config{dbhost}" if $config{dbhost};
  $dsn .= ";port=$config{dbport}" if $config{dbport};
  return DBI->connect($dsn, $config{dbuser}, $config{dbpass}, \%attr);
}

sub load_config ()
{
  open(FH, $CONFIG_FILE) or return "$CONFIG_FILE: $!";
  foreach (map { s/\r|\n//sgio; $_ } <FH>) {
    next if /^$/;
    next if /^#/;
    next if /^;/;
    next if /^\/\//;
    next unless /^([^\s]+)\s+=\s+(.+)$/;
    my $key = $1;
    my $value = $2;
    foreach (keys %DEFAULTS) {
      if ($key eq $_) {
        $config{$_} = $value;
        last;
      }
    }
  }
  close(FH);
  return "";
}

1;

==> graypold-0.3.tar.bz2: graypold-0.3/graylib.pl <==
#!/usr/bin/perl -w

use strict;
use warnings;
use DBI;

our $CONFIG_FILE		= "/usr/local/etc/graypol.conf";
my %DEFAULTS;
$DEFAULTS{"dbtype"}		= "Pg";
$DEFAULTS{"dbhost"}		= "";
$DEFAULTS{"dbport"}		= "";
$DEFAULTS{"dbuser"}		= "";
$DEFAULTS{"dbpass"}		= "";
$DEFAULTS{"dbname"}		= "";
$DEFAULTS{"db_tbl_gray"}	= "graylist";
$DEFAULTS{"db_tbl_bw"}		= "blackwhitelist";
$DEFAULTS{"db_tbl_mailcount"}	= "mailcount";
$DEFAULTS{"db_field_ok"}	= "ok";
$DEFAULTS{"db_field_ip"}	= "ip";
$DEFAULTS{"db_field_from"}	= "\"from\"";
$DEFAULTS{"db_field_to"}	= "\"to\"";
$DEFAULTS{"db_field_ts_entry"}	= "ts_entry";
$DEFAULTS{"db_field_ts_latest"}	= "ts_latest";
$DEFAULTS{"db_field_ts_ok"}	= "ts_ok";
$DEFAULTS{"db_field_count"}	= "count";
$DEFAULTS{"db_key_err"}		= "duplicate key violates unique constraint";
$DEFAULTS{"listen"}		= "/var/run/graypold.sock";
$DEFAULTS{"owner"}		= "postfix";
$DEFAULTS{"rights"}		= "0600";
$DEFAULTS{"port"}		= "6666";
$DEFAULTS{"backlog"}		= "128";
$DEFAULTS{"pidfile"}		= "/var/run/graypold.pid";

$DEFAULTS{"lockfile"}		= "/var/lock/graycron.lock";
$DEFAULTS{"rrdfile"}		= "/var/db/graylist.rrd";
$DEFAULTS{"rrdfile2"}		= "/var/db/mailcount.rrd";
$DEFAULTS{"picpath"}		= "/usr/local/www/data";
$DEFAULTS{"delay_permit"}	= "interval '3 minutes'";
$DEFAULTS{"delay_halfopen"}	= "interval '12 hours'";
$DEFAULTS{"delay_max"}		= "interval '35 days'";

our %config = %DEFAULTS;

sub dbopen ()
{
  my %attr = ( RaiseError => 1, PrintError => 0, HandleError => $_[0] ) if $_[0];
  my $dsn = "DBI:$config{dbtype}:dbname=$config{dbname}";
  $dsn .= ";host=$config{dbhost}" if $config{dbhost};
  $dsn .= ";port=$config{dbport}" if $config{dbport};
  return DBI->connect($dsn, $config{dbuser}, $config{dbpass}, \%attr);
}

sub load_config ()
{
  open(FH, $CONFIG_FILE) || return "$CONFIG_FILE: $!";
  foreach (map { s/\r|\n//sgio; $_ } <FH>) {
    next if /^$/;
    next if /^#/;
    next if /^;/;
    next if /^\/\//;
    next unless /^([^\s]+)\s+=\s+(.+)$/;
    my $key = $1;
    my $value = $2;
    foreach (keys %DEFAULTS) {
      if ($key eq $_) {
        $config{$_} = $value;
        last;
      }
    }
  }
  close(FH);
  return "";
}

1;
